@@ -1,8 +1,8 @@
 /***************************************************
-* unit:    strings           release 0.24          *
+* unit:    strings           release 0.25          *
 * purpose: general manipulation with text strings  *
 * Licency: GPL or LGPL                             *
-* Copyright: (c) 1998-2021 Jaroslav Fojtik         *
+* Copyright: (c) 1998-2022 Jaroslav Fojtik         *
 ****************************************************/
 /* NOTE: strings.h clashes with standard headers, thus stringa.h */
 #ifndef __Stringa_h
@@ -98,6 +98,9 @@ public:   string(void)				{size=maxlen=0;ch=0;};
 	  inline char &operator[](const unsigned long i) const {if(i>=size) return(Dummy=0); return(ch[i]);}
 	  inline char &operator[](const int i) const {if((unsigned)i>=size || i<0) return(Dummy=0); return(ch[i]);}
 	  inline char &operator[](const long i) const {if((unsigned long)i>=size || i<0) return(Dummy=0); return(ch[i]);}
+#ifdef FIX_LONGLONG
+	  inline char &operator[](const unsigned long long i) const {if(i>=size) return(Dummy=0); return(ch[i]);}
+#endif
 
 //	  char *operator IN(const char *str) {return(StrStr(str,ch));}
 	  friend char *operator IN(const char *str,const string &s) {return(StrStr(s.ch,str));}
