@@ -1,9 +1,10 @@
-/**************************************************
-* unit:    struct            release 0.12         *
-*   STRUCT.C - Provides some big and little endian abstraction functions,
-*	      for manipulating with structures.	
-*   Copyright (C) 1999-2020  Jaroslav Fojtik
-***************************************************/
+/*************************************************************************
+* unit:    struct            release 0.13                                *
+*   struct.c - Provides some big and little endian abstraction functions,
+*	      for manipulating with structures.
+* Licency: GPL or LGPL                                                   *
+*   Copyright (C) 1999-2022  Jaroslav Fojtik
+**************************************************************************/
 #include <stdio.h>
 #include <stdarg.h>
 #include <ctype.h>
@@ -27,6 +28,7 @@
  #if _MSC_VER > 1200	/* Not present in MSVC6 or less. */
   #include <stdlib.h>
   #define BYTESWAP_uint64(__pval) __pval=_byteswap_uint64(__pval)
+  #define BYTESWAP_uint32(__pval) __pval=_byteswap_ulong(__pval)
  #endif
 #endif
 
@@ -158,7 +160,7 @@ return 2;
 /* Read a double word from binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
  * return:     DWORD *num : readed double word  */
-int RdDWORD_HiEnd( DWORD *num, FILE *f )
+int RdDWORD_HiEnd(DWORD *num, FILE *f)
 {
 #ifdef LO_ENDIAN
 const int i = fread(num,1,4,f);
@@ -185,7 +187,7 @@ return 4;
 /* Read a quad word from binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
  * return:     DWORD *num : readed double word  */
-int RdQWORD_HiEnd(QWORD_ *num, FILE *f )
+int RdQWORD_HiEnd(QWORD_ *num, FILE *f)
 {
 #ifdef LO_ENDIAN
 const int i = fread(num,1,8,f);
@@ -260,7 +262,7 @@ return 4;
 /* Write a word to the binary file in a HighEndian Format
  * parameters: FILE  *f :  binary input file
  *             WORD num : word to be written */
-int WrWORD_HiEnd( WORD num, FILE *f )
+int WrWORD_HiEnd(WORD num, FILE *f)
 {
 #ifdef HI_ENDIAN
   return(fwrite(&num,1,2,f));
@@ -278,7 +280,7 @@ return 2;
 /* Write a double word to the binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
  *             DWORD num : double word to be written */
-int WrDWORD_HiEnd(DWORD num, FILE *f )
+int WrDWORD_HiEnd(DWORD num, FILE *f)
 {
 #ifdef HI_ENDIAN
   return(fwrite(&num,1,4,f));
@@ -304,7 +306,7 @@ return 4;
 /* Write a quad word to the binary file in a HiEndian Format
  * parameters: FILE  *f :  binary input file
  *             DWORD num : double word to be written */
-int WrQWORD_HiEnd(QWORD_ num, FILE *f )
+int WrQWORD_HiEnd(QWORD_ num, FILE *f)
 {
 #ifdef HI_ENDIAN
   return(fwrite(&num,1,8,f));
@@ -333,7 +335,7 @@ return 8;
 /* Write a quad word to the binary file in a LowEndian Format
  * parameters: FILE  *f :  binary input file
  *             DWORD num : double word to be written */
-int WrQWORD_LoEnd(QWORD_ num, FILE *f )
+int WrQWORD_LoEnd(QWORD_ num, FILE *f)
 {
 #ifdef LO_ENDIAN
   return(fwrite(&num,1,8,f));
@@ -359,7 +361,7 @@ return 8;
 
 
 /** Read a WORD from byte stream. */
-WORD fil_sreadU16 (const BYTE *in)
+WORD fil_sreadU16(const BYTE *in)
 {
 #ifdef LO_ENDIAN
  return *(WORD *)in;
@@ -371,7 +373,7 @@ WORD fil_sreadU16 (const BYTE *in)
 
 
 /** Read a DWORD from byte stream. */
-DWORD fil_sreadU32 (const BYTE *in)
+DWORD fil_sreadU32(const BYTE *in)
 {
 #ifdef LO_ENDIAN
  return *(DWORD *)in;
@@ -384,7 +386,6 @@ DWORD fil_sreadU32 (const BYTE *in)
 }
 
 
-
 int loadstruct(FILE *F,const char *description, ...)
 {
  va_list ap;
@@ -443,9 +444,9 @@ int savestruct(FILE *F,const char *description, ...)
  int ArraySize;
 
  va_start(ap, description);
+
  while(*description!=0)
    {
-
    switch(*description)
      {     
 #ifndef __Ellipsis_Expand_Short
@@ -453,9 +454,9 @@ int savestruct(FILE *F,const char *description, ...)
      case 'B':{const char c = va_arg(ap,char);
 	      writed+=fwrite(&c,1,1,F);}
               break;	
-     case 'w':writed+=WrWORD_LoEnd( va_arg(ap,WORD),F);
+     case 'w':writed += WrWORD_LoEnd(va_arg(ap,WORD),F);	          
      	      break;
-     case 'W':writed+=WrWORD_HiEnd( va_arg(ap,WORD),F);
+     case 'W':writed+=WrWORD_HiEnd(va_arg(ap,WORD),F);
      	      break;
 #else	//all shorts are internally converted to int
      case 'b':
@@ -482,9 +483,9 @@ int savestruct(FILE *F,const char *description, ...)
 
               writed+=fwrite(va_arg(ap,char *),1,ArraySize,F);
               break;
-     case 'q':writed+=WrQWORD_LoEnd( va_arg(ap,QWORD_),F);
+     case 'q':writed+=WrQWORD_LoEnd(va_arg(ap,QWORD_),F);	      
      	      break;
-     case 'Q':writed+=WrQWORD_HiEnd( va_arg(ap,QWORD_),F);
+     case 'Q':writed+=WrQWORD_HiEnd(va_arg(ap,QWORD_),F);
      	      break;
 
      default:printf("Error: Unknown character %c !", *description);
@@ -496,4 +497,3 @@ int savestruct(FILE *F,const char *description, ...)
 
 return(writed);
 }
-
