@@ -4,6 +4,7 @@
  * modul:       cpbldr.cc						      *
  * description: The executable for generating codetables will be generated    *
  *		after compiling this module.				      *
+ * licency:     GPL		                                              *
  ******************************************************************************/
 #include "cplib.cc"
 
@@ -11,7 +12,6 @@
 #include "../jobs/csext.h"
 #endif
 
-
 #if defined(__DJGPP__) || defined(_WIN32)
  #define DIR_DEPARATOR '\\'
 #else
@@ -240,11 +240,24 @@ return plain;
 }
 
 
-void ForgeFname(string &str, const char *Fname)
+void ForgeFname(string &str, const char *Fname, bool Erase=true)
 {
+FILE *F;
+
  str = Directory;
  if(str.length()>0) str+=DIR_DEPARATOR;
  str += Fname;
+
+ if(Erase)
+ {
+   F = fopen(str(),"rb");
+   if(F != NULL)
+   {
+     fclose(F);
+     printf("Old file \"%s\" exists!\n", str());
+     remove(str());
+   }
+ }
 }
 
 
@@ -473,7 +486,7 @@ int main(int argc, char *argv[])
 {
 FILE *F;
 codepage internal;
-codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1255, cp1276, cpkam,
+codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
 	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4,
          unicode,koi8cs,koi8r,
@@ -485,7 +498,7 @@ Translator trn;
 doublelist llHTML;
 string FileName;
 
- puts("<<<cplib>>> (c)1999-2021 J.Fojtik");
+ puts("<<<cplib>>> (c)1999-2022 J.Fojtik");
 
  if(argc>1)
    {
@@ -503,7 +516,7 @@ string FileName;
 
 #if !defined(__DJGPP__)
  //Sleep(1000);
- ForgeFname(FileLock,"lock.lck");
+ ForgeFname(FileLock,"lock.lck",false);
  while((Flock=fopen(FileLock(),"rb")) != NULL)
  {
    fclose(Flock);
@@ -552,6 +565,7 @@ string FileName;
  if(!LoadCodePage("cp1251",cp1251,0)) return -5;
  if(!LoadCodePage("cp1252",cp1252,0)) return -6;
  if(!LoadCodePage("cp1253",cp1253,0)) return -7;
+ LoadCodePage("cp1254",cp1254,0);
  if(!LoadCodePage("cp1255",cp1255,0)) return -8;
  if(!LoadCodePage("cp1276",cp1276,0)) return -9;
 
@@ -575,7 +589,7 @@ string FileName;
 
 
  ForgeFname(FileName, "trn.new");
- if((F=fopen(FileName(),"w"))==NULL)
+ if((F=fopen(FileName(),"wb"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
    return -1;
@@ -670,6 +684,9 @@ WriteTranslator(cp1250,cpkam,trn,F);
  CreateTranslator(trn,cp1253,internal);
  WriteTranslator(cp1253,internal,trn,F);
 
+ CreateTranslator(trn,cp1254,internal);
+ WriteTranslator(cp1254,internal,trn,F);
+
  CreateTranslator(trn,cp1255,internal);
  WriteTranslator(cp1255,internal,trn,F);
 
