@@ -1288,6 +1288,7 @@ TextContainer::TextContainer()
   FontOrientation = 0;
   RotCenterX = RotCenterY = 0;
   TextAllign = 0;
+  MixMode = 0;
 }
 
 
@@ -1332,7 +1333,7 @@ return LineNoAccent;
 /// @param[in,out]	str	String that needs either cleanup or adding \show.
 /// @param[in,out]	strLine Newly added chunk of text. Will be erased on return.
 /// @param[in]		HorizontalPos	Horizontal position placement.
-void AppendShow(string &str, string &strLine, const unsigned char HorizontalPos)
+void AppendShow(string &str, string &strLine, const unsigned char HorizontalPos, const string &Override)
 {
   int len = length(strLine);
   if(len==0) return;
@@ -1379,6 +1380,9 @@ void AppendShow(string &str, string &strLine, const unsigned char HorizontalPos)
 	    break;
     default: str += strLine;
     }
+
+  str += Override;
+
   str += "\nshow";
   erase(strLine);
 }
@@ -1391,13 +1395,36 @@ RGB_Record BkTextColor;
 float CurPosX = PosX;
 float CurPosY = PosY;
 const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
+string Override;
 
   if(Text!=NULL && TextObjects>0)
-  {
+  {    
     if(PSS!=NULL)
     {    
       PS_Attr(str,PSS);   
       memcpy(&BkTextColor,&PSS->LineColor,sizeof(RGB_Record));
+      if(MixMode==2)
+          Override.printf("\ngsave dup"
+			"\ntrue charpath pathbbox"	//llx lly urx ury
+			"\n3 index"			//llx lly urx ury llx
+			" 3 index"			//llx lly urx ury llx lly
+			"\nmoveto"			//llx lly urx ury (llx lly)
+			"\n1 index"			//llx lly urx ury urx
+			" 3 index"			//llx lly urx ury urx lly
+			"\nlineto"			//llx lly urx ury (urx lly)
+			"\n1 index"
+			" 1 index"
+			"\nlineto"			//llx lly urx ury (urx ury)
+			"\n3 index"
+			" 1 index"
+			"\nlineto"
+			"\npop pop pop pop"
+			"\nclosepath"
+			"\n%0.2g %0.2g %0.2g setrgbcolor"
+			"\nfill grestore",
+			  (float)PSS->FillBackground.Red/256.0,
+			  (float)PSS->FillBackground.Green/256.0,
+			  (float)PSS->FillBackground.Blue/256.0);
     }
     if(TextRotated)
     {
@@ -1418,7 +1445,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         FixPsAccent(Text[i]->contents,"\\\"{","(\\310)");	// umlaut
         FixPsAccent2(Text[i]->contents,"\\accent39","( \\47)"); //insert space before apostrophe \\47
         
-        if(i>0) AppendShow(str,strLine,TextAllign);
+        if(i>0) AppendShow(str,strLine,TextAllign,Override);
 	
         if(PSS!=NULL)
         {
@@ -1464,7 +1491,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
 	  ScanS = ScanS2 + 1;
 
 	  CurPosY -= 1.01 * Text[i]->size*2.66f;
-	  AppendShow(str,strLine,TextAllign);
+	  AppendShow(str,strLine,TextAllign,Override);
 	  str.cat_printf(" newpath %2.2f %2.2f moveto", CurPosX, CurPosY);
 	}
 
@@ -1476,7 +1503,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         }
       }      
     }
-    AppendShow(str,strLine,TextAllign);
+    AppendShow(str,strLine,TextAllign,Override);
     if(TextRotated)
     {    
       str += "\ngrestore";
