@@ -160,8 +160,8 @@ void TconvertedPass1_WP4::Comment4(DWORD & NewPos, WORD & w)
   strcpy(ObjType, "Comment");
   attr = OldAttr;
   flag = OldFlag;
-  if(Old_char_on_line==true || Old_char_on_line==-1) char_on_line = -1;
-	else char_on_line = false;
+  if(Old_char_on_line==CHAR_PRESENT || Old_char_on_line==JUNK_CHARS) char_on_line = JUNK_CHARS;
+	else char_on_line = NO_CHAR;
 }
 
 
@@ -324,13 +324,13 @@ void TconvertedPass1_WP4::Header_Footer4(DWORD & NewPos, WORD & w)
   recursion++;
 
   line_term = 's';    	//Soft return
-  if(char_on_line == -20)    /* Left one enpty line for new enviroment */
+  if(char_on_line == LEAVE_ONE_EMPTY_LINE)  // Left one enpty line for new enviroment.
       {
       fputc('%', table);
       fputc('%', strip);
       NewLine(this);
       }
-  if(char_on_line==true)
+  if(char_on_line==CHAR_PRESENT)
       {
       NewLine(this);
       }
@@ -345,7 +345,7 @@ void TconvertedPass1_WP4::Header_Footer4(DWORD & NewPos, WORD & w)
   ActualPos = PosX;
   envir = ' ';
   flag = HeaderText;
-  char_on_line = -10;
+  char_on_line = FIRST_CHAR_MINIPAGE;
   while (!feof(wpd))
        {
        fread(&by, 1, 1, wpd);
@@ -356,7 +356,7 @@ void TconvertedPass1_WP4::Header_Footer4(DWORD & NewPos, WORD & w)
        }
 
   Close_All_Attr(attr,strip);
-  if(char_on_line==true)
+  if(char_on_line==CHAR_PRESENT)
      {
      line_term = 's';    	//Soft return
      NewLine(this);
@@ -372,7 +372,7 @@ void TconvertedPass1_WP4::Header_Footer4(DWORD & NewPos, WORD & w)
   attr = OldAttr;
   flag = OldFlag;
   envir= OldEnvir;
-  char_on_line = -10;
+  char_on_line = FIRST_CHAR_MINIPAGE;
 
 EndHeaderFooter:
   LogLevel=SaveLLevel;
