@@ -487,12 +487,12 @@ do {
   if(FieldCount>0)
     {
     line_term = 's';   /* Soft return */
-    if(char_on_line == -20)    /* Left one enpty line for new enviroment */
+    if(char_on_line == LEAVE_ONE_EMPTY_LINE)    /* Left one enpty line for new enviroment */
 	{
 	fputc('%', table); fputc('%', strip);
 	NewLine(this);
 	}
-    if(char_on_line>=true) //  if(cq->char_on_line>=-1)
+    if(char_on_line>=CHAR_PRESENT) //  if(cq->char_on_line>=-1)
 	{
 	NewLine(this);
 	}
@@ -560,7 +560,7 @@ do {
 	}
 
 FinishTable:
-  if(char_on_line <= -10)    /* Left one enpty line for ending enviroment */
+  if(char_on_line <= FIRST_CHAR_MINIPAGE)  /* Left one enpty line for ending enviroment */
 	{
 	fputc('%', table);fputc('%', strip);
 	NewLine(this);
@@ -568,7 +568,7 @@ FinishTable:
   envir = '^';		//Ignore enviroments after table
   fputc('%', table);
   NewLine(this);
-  char_on_line = -10;		// stronger false;
+  char_on_line = FIRST_CHAR_MINIPAGE;	// stronger false;
 
   recursion--;
 
