@@ -53,12 +53,12 @@ long FilePos;
   cq->recursion++;
 
   cq->line_term = 's';   /* Soft return */
-  if(cq->char_on_line == -20)    /* Left one enpty line for new enviroment */
+  if(cq->char_on_line == LEAVE_ONE_EMPTY_LINE)  /* Left one enpty line for new enviroment */
 	{
 	fputc('%', cq->table);fputc('%', cq->strip);
 	NewLine(cq);
 	}
-  if(cq->char_on_line>=true) //  if(cq->char_on_line>=-1)
+  if(cq->char_on_line>=CHAR_PRESENT) //  if(cq->char_on_line>=-1)
 	{
 	NewLine(cq);
 	}
@@ -99,7 +99,7 @@ long FilePos;
 
   fprintf(cq->strip, "\\end{itemize}");
   if(OldEnvir=='B') fprintf(cq->strip, "}");
-  if(cq->char_on_line <= -10)    /* Left one enpty line for ending enviroment */
+  if(cq->char_on_line <= FIRST_CHAR_MINIPAGE) // Left one enpty line for ending enviroment.
 	{
 	fputc('%', cq->table);fputc('%', cq->strip);
 	NewLine(cq);
@@ -107,13 +107,13 @@ long FilePos;
   cq->envir='^';		//Ignore enviroments after table
   fputc('%', cq->table);
   NewLine(cq);
-  cq->char_on_line = -10;		// stronger false;
+  cq->char_on_line = FIRST_CHAR_MINIPAGE;		// stronger false;
 
   cq->recursion--;
 
-  cq->flag=OldFlag;
-  cq->envir=OldEnvir;
-cq->TAG="ITEMIZE";
+  cq->flag = OldFlag;
+  cq->envir = OldEnvir;
+  cq->TAG = "ITEMIZE";
 strcpy(cq->ObjType, "Itemize Start");
 }
 
