@@ -367,12 +367,12 @@ long FilePos;
   recursion++;
 
   line_term = 's';   /* Soft return */
-  if(char_on_line == -20)    /* Left one enpty line for new enviroment */
+  if(char_on_line == LEAVE_ONE_EMPTY_LINE)  // Left one enpty line for new enviroment
 	{
 	fputc('%', table);fputc('%', strip);
 	NewLine(this);
 	}
-  if(char_on_line>=true) //  if(char_on_line>=-1)
+  if(char_on_line>=CHAR_PRESENT) //  if(char_on_line>=-1)
 	{
 	NewLine(this);
 	}
@@ -413,21 +413,21 @@ long FilePos;
 
   fprintf(strip, "\\end{itemize}");
   if(OldEnvir=='B') fprintf(strip, "}");
-  if(char_on_line <= -10)    /* Left one enpty line for ending enviroment */
+  if(char_on_line <= FIRST_CHAR_MINIPAGE)  // Left one enpty line for ending enviroment.
 	{
 	fputc('%', table);fputc('%', strip);
 	NewLine(this);
 	}
-  envir='^';		//Ignore enviroments after table
+  envir = '^';		//Ignore enviroments after table
   fputc('%', table);
   NewLine(this);
   char_on_line = -10;		// stronger false;
 
   recursion--;
 
-  flag=OldFlag;
-  envir=OldEnvir;
-TAG="ITEMIZE";
+  flag = OldFlag;
+  envir = OldEnvir;
+  TAG = "ITEMIZE";
 strcpy(ObjType, "Itemize Start");
 }
 
@@ -550,12 +550,12 @@ do {
   if(FieldCount>0)
     {
     line_term = 's';   /* Soft return */
-    if(char_on_line == -20)    /* Left one enpty line for new enviroment */
+    if(char_on_line == LEAVE_ONE_EMPTY_LINE)  // Left one enpty line for new enviroment.
 	{
 	fputc('%', table);fputc('%', strip);
 	NewLine(this);
 	}
-    if(char_on_line>=true) //  if(char_on_line>=-1)
+    if(char_on_line>=CHAR_PRESENT) //  if(char_on_line>=-1)
 	{
 	NewLine(this);
 	}
@@ -596,7 +596,7 @@ do {
 
 	ReadXMLTag();
 	}
-  if(char_on_line <= -10)    /* Left one enpty line for ending enviroment */
+  if(char_on_line <= FIRST_CHAR_MINIPAGE)  // Left one enpty line for ending enviroment.
 	{
 	fputc('%', table);fputc('%', strip);
 	NewLine(this);
@@ -604,13 +604,13 @@ do {
   envir='^';		//Ignore enviroments after table
   fputc('%', table);
   NewLine(this);
-  char_on_line = -10;		// stronger false;
+  char_on_line = FIRST_CHAR_MINIPAGE;	// stronger false;
 
   recursion--;
 
   flag = OldFlag;
   envir = OldEnvir;
-TAG="TABLE";
+  TAG = "TABLE";
 strcpy(ObjType, "Table Start");
 }
 
