@@ -212,7 +212,7 @@ switch(Selector)
 	   case 4:return("\\oint\\nolimits_{2} 1 !3");	//21.4=integrals: contour - lower only
 	   }
 	  break;
-  case 22:if(Wasy>=false)
+  case 22:if(Wasy>=STYLE_NOTUSED)
             {
 	    switch(Variation)
 	      {
@@ -230,7 +230,7 @@ switch(Selector)
 	    case 3:return("\\int\\int\\nolimits_{2} 1 !3"); //22.3=integrals: area - lower only
             }
 	  break;
-  case 23:if(Wasy>=false)
+  case 23:if(Wasy>=STYLE_NOTUSED)
             {
             switch(Variation)
 	      {
@@ -255,7 +255,7 @@ switch(Selector)
 	   case 2:return("\\oint\\limits_{2} 1 !3");	 //24.2=integrals: contour - sum style - lower only
 	   }
 	  break;
-  case 25:if(Wasy>=false)
+  case 25:if(Wasy>=STYLE_NOTUSED)
             {
   	    switch(Variation)
 	      {
@@ -269,7 +269,7 @@ switch(Selector)
 	    case 1:return("\\int\\int\\limits_{2} 1 !3");	//25.1=integrals: double - sum style - lower only
 	    }
 	  break;
-  case 26:if(Wasy>=false)
+  case 26:if(Wasy>=STYLE_NOTUSED)
             {
 	    switch(Variation)
 	      {
@@ -623,15 +623,15 @@ static void MTEF_LINE(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_LINE() ");fflush(cq->log);
 #endif
-BYTE OldBy,Ruller;
+BYTE OldBy, Ruller;
 SWORD LineSpacing;
 
- static int LineNo=0;
- int iLineNo=LineNo++;
+ static int LineNo = 0;
+ int iLineNo = LineNo++;
 
  if(cq->Version<=0x3FF)
       {
-      cq->subby=cq->by>>4;
+      cq->subby = cq->by>>4;
       if(cq->subby & 8) Rd_nudge(cq->wpd, cq->nudge);
       if(cq->subby & 4) Ruller=fgetc(cq->wpd);
       if(cq->subby & 1)	{sprintf(cq->ObjType, "LINE{}");return;}
@@ -643,7 +643,7 @@ SWORD LineSpacing;
       if(cq->subby & MtefO_LINE_NULL) {sprintf(cq->ObjType, "LINE{}");return;}
       }
 
- OldBy=cq->by;
+ OldBy = cq->by;
  if(cq->log!=NULL)
 	fprintf(cq->log,"\n%*s[LINE #%d]",cq->recursion * 2,"",iLineNo);
  cq->recursion++;
@@ -1216,7 +1216,7 @@ bool Line=false;
       ProcessKeyMTEFSymbol(this);
       }
 
-  if(Formula!="")
+  if(!Formula.isEmpty())
     {
     int i,j;
 
