@@ -481,7 +481,7 @@ static int ecParseChar(TconvertedPass1_RTF *cq, int ch)
 		   {
 		   case  9:return(ecOK);// ecPrintChar(cq,'\t'); - ignore tabulator
 		   case 10:
-		   case 13:if(cq->char_on_line==true) NewLine(cq);
+		   case 13:if(cq->char_on_line==CHAR_PRESENT) NewLine(cq);
 			   break;
 		   default:if(ch==0) return(ecOK); // unfortunately, we don't do a whole lot here as far as layout goes...
 			   if(memcmp(&cq->NewRGB,&cq->RGB,sizeof(RGBQuad)))
@@ -666,7 +666,7 @@ static int ecPopRtfState(TconvertedPass1_RTF *cq)
 	{
 	cq->envir=cq->pap.envir;
 	if(cq->envir != ' ')
-		cq->char_on_line = -20;
+		cq->char_on_line = LEAVE_ONE_EMPTY_LINE;
 	}
     return ecOK;
 }
@@ -1156,12 +1156,12 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
   cq->recursion++;
 
   cq->line_term = 's';    	//Soft return
-  if(cq->char_on_line == -20)    /* Left one enpty line for new enviroment */
+  if(cq->char_on_line == LEAVE_ONE_EMPTY_LINE)  // Left one enpty line for new enviroment.
       {
       fputc('%', cq->strip);
       NewLine(cq);
       }
-  if(cq->char_on_line==true)
+  if(cq->char_on_line==CHAR_PRESENT)
       {
       NewLine(cq);
       }
@@ -1174,7 +1174,7 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
 
   cq->envir = ' ';
   cq->flag = HeaderText;
-  cq->char_on_line = -10;
+  cq->char_on_line = FIRST_CHAR_MINIPAGE;
   while (!feof(cq->wpd) && CurlyBaraceStack > 0)
 	{
 	cq->subby=RTFLoadKeyword(cq);
@@ -1208,7 +1208,7 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
   cq->ActualPos = ftell(cq->wpd);
 
   Close_All_Attr(cq->attr,cq->strip);
-  if(cq->char_on_line==true)
+  if(cq->char_on_line==CHAR_PRESENT)
      {
      cq->line_term = 's';    	//Soft return
      NewLine(cq);
@@ -1224,7 +1224,7 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
   cq->attr = OldAttr;
   cq->flag = OldFlag;
   cq->envir= OldEnvir;
-  cq->char_on_line = -10;
+  cq->char_on_line = FIRST_CHAR_MINIPAGE;
 
   strcpy(cq->ObjType, ((HFtype & 3) <= 1)?"Header":"Footer");
 }
@@ -1585,7 +1585,7 @@ int KeywordType;
 	    break;
      case 3:return ecInvalidHex;		    //Bad Hex
      case 0xA:
-     case 0xD:if(cq->char_on_line==true) NewLine(cq);
+     case 0xD:if(cq->char_on_line==CHAR_PRESENT) NewLine(cq);
 		      break;          // cr and lf are noise characters...    - EOL;
      case 200:if ((ec = ecPushRtfState(cq)) != ecOK)	// {
 			 return ec;
