@@ -74,23 +74,23 @@ Flags:'h';       Hard return
 		-10 Line before nested enviroment change
 		 -1 No valic character on line, but previous line plays like character
 		  0 No valid character on the line
-		  1 Valid character placed on the line*/
+		  1 Valid character placed on the line */
 
 /*WP2LaTex switches: -1:disabled; 0:automatically enabled; 1: forced to enable*/
-SBYTE   Accents = false,
+SBYTE   Accents = STYLE_NOTUSED,
 	AmsMath = -1,
         Amssymb = -1,		// Totaly Disabled
 	Arevmath = -1,		// Totaly Disabled
-        Cyrillic = false,
-	cjHebrew = false,
-	colors = false,		// Only for LaTex 2.0e
+        Cyrillic = STYLE_NOTUSED,
+	cjHebrew = STYLE_NOTUSED,
+	colors = STYLE_NOTUSED,	// Only for LaTex 2.0e
 	textcomp = -1,
-	EndNotes=false,
+	EndNotes = STYLE_NOTUSED,
 	FancyHdr = -1,
 	Columns = 1,		// -1 disabled; 0 auto two; 1 auto multi; 2 forced two; >2 forced multi*/
 	InputPS = IMG_graphicx,	// -1 disabled; 0 auto InputPS.sty; 1 InputPS.sty; 2 auto graphicx.sty; 3 graphicx.sty; 4 auto epsfig.sty; 5 epsfig.sty; 8 auto graphics.sty; 9 graphics.sty;
-	pifont = false,
-	PostScript = false,
+	pifont = STYLE_NOTUSED,
+	PostScript = STYLE_NOTUSED,
 	MakeIdx = -1,
 	Wasy = -1,		// Totaly Disabled	
 	LaTeXsym = 0,
@@ -102,9 +102,9 @@ SBYTE   Accents = false,
 	rus_yo = 0,
 	LongTable = -1,
 	SaveWPG = -1,
-        Rotate = false,
-        Scalerel = false,
-	LineNo = false;
+        Rotate = STYLE_NOTUSED,
+        Scalerel = STYLE_NOTUSED,
+	LineNo = STYLE_NOTUSED;
 bool Index = false,
         Interactive = true,
 	NFSS = false,
@@ -1088,15 +1088,19 @@ long FilePos;
 	   case 2:iFFD.DocVersion=0x600 + (WORD)(ver>>8);
 		  if(iFFD.DocVersion>=0x602) iFFD.DocVersion+=0xFE;
 		  if(encryption==0) iFFD.Converter="WP6.x";
-			       else iFFD.Converter="WP6.x encrypted";
+		  else
+		    {
+		    iFFD.Converter="WP6.x encrypted";
+		    fprintf(err,_(EncryptionWarning));
+		    }
 		  break;
 	   default:iFFD.DocVersion=0x500l + (WORD)(ver>>8) + 256*(ver & 0xFF);
 		   iFFD.Converter="WP6.x";	/* Place here -FORCE warning */
 		   fprintf(err,_("\nWarning: Unknown WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,iFFD.DocVersion>>8,iFFD.DocVersion & 0xFF);
+		   if(encryption!=0) fprintf(err,_(EncryptionWarning));
 		   encryption=0;
 	   }
-
-	if(encryption!=0) fprintf(err,_(EncryptionWarning));
+	
 	}
     /*if (filetype == 0xA20)
 	{
@@ -1988,7 +1992,7 @@ UnknownArg:
 
   if(latex_filename == '-') Verbosing=0;
 
-  if(Amssymb>=false && LaTeX_Version<0x300)
+  if(Amssymb>=STYLE_NOTUSED && LaTeX_Version<0x300)
 	fprintf(err,_("\nWarning: Package \"amssymb\" should not be used in LaTeX 2.09!"));
 
   //StrName = getenv("LANGUAGE");  ?? Na co to tu je ??
