@@ -413,7 +413,7 @@ void ShowHelp(void)
 
 void ShowCopyright(void)
 {
-  puts(_("\nThis program and related files are copyright (c) 1996-2017 Fojtik Jaroslav."
+  puts(_("\nThis program and related files are copyright (c) 1996-2022 Fojtik Jaroslav."
 	 "\nThis code can be redistributed and/or modified under the terms of the GNU"
 	 "\nGeneral Public License available from: http://www.gnu.org/copyleft/gpl.html."
 	 "\nWith one additional requirement:"
@@ -542,7 +542,7 @@ static void CheckOptions(void)
 {
  if(LaTeX_Version<0x300)		//disable colors for LaTeX 2.09
    {
-   if(colors>true)
+   if(colors > 1)
 	fprintf(err,_("Warning: Color style is available only for LaTeX 2e !\n"));
    colors=-1;
    }
@@ -627,6 +627,7 @@ char str[20];
  {
    Heading();
    fprintf(err,_("\nFatal: Compillation has been optimised for pointer size %ubits, pointer size is %ubits!"), POINTER_SIZE, (unsigned)sizeof(void*)*8);
+   Interactive = false;	// This problem is really unpleasant, abort app.
    AskUser();
  }
 #endif
